@@ -372,8 +372,9 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     You can define a wrapper to transform the initial object into an output of your
     choice to be rendered:
 
+    >>> from front.app_maker_base import dflt_trans
     >>> def trans(objs: Iterable):
-    ...     return list(reversed(objs))
+    ...     return dflt_trans(reversed(objs))
     >>> config = {
     ...     'obj': {
     ...         'trans': trans
@@ -386,13 +387,13 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     For instance, you can choose to render a text input instead of a number input for a
     specific parameter of a specific function:
 
-    >>> from front.elements import COMPONENT_INT_SLIDER
+    >>> from front.elements import INT_INPUT_SLIDER_COMPONENT
     >>> config = {
     ...     'rendering': {
     ...         'Foo': {
     ...             'inputs': {
     ...                 'a': {
-    ...                     'component': COMPONENT_INT_SLIDER,
+    ...                     'component': INT_INPUT_SLIDER_COMPONENT,
     ...                     'max_value': 10
     ...                 }
     ...             }
@@ -414,7 +415,7 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     ...         'Foo': {
     ...             'inputs': {
     ...                 'a': {
-    ...                     'component': COMPONENT_INT_SLIDER,
+    ...                     'component': INT_INPUT_SLIDER_COMPONENT,
     ...                     'max_value': 10
     ...                 }
     ...             }
@@ -428,7 +429,16 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     make sure that all configuations are defined. Otherwise, the application would
     crash or behave unexpectedly.
 
-    >>> from front.elements import CONTAINER_VIEW, COMPONENT_FLOAT_SLIDER, COMPONENT_TEXT
+    >>> from meshed import DAG
+    >>> from front.elements import (
+    ...     VIEW_CONTAINER,
+    ...     FLOAT_INPUT_SLIDER_COMPONENT,
+    ...     TEXT_INPUT_COMPONENT,
+    ...     EXEC_SECTION_CONTAINER,
+    ...     SECTION_CONTAINER,
+    ...     GRAPH_COMPONENT
+    ... )
+    >>> 
     >>> convention = {
     ...     'app': {
     ...         'title': 'Another application name'
@@ -437,18 +447,27 @@ def mk_app(objs: Iterable, config: Map = None, convention: Map = None):
     ...         'trans': trans
     ...     },
     ...     'rendering': {
-    ...         Callable: {
-    ...             'container': CONTAINER_VIEW,
-    ...             'inputs': {
-    ...                 float: {
-    ...                     'component': COMPONENT_FLOAT_SLIDER,
-    ...                     'format': '%.2f',
-    ...                     'step': 0.01,
-    ...                 },
-    ...                 Any: {
-    ...                     'component': COMPONENT_TEXT,
+    ...         DAG: {
+    ...             'container': VIEW_CONTAINER,
+    ...             'execution': {
+    ...                 'container': EXEC_SECTION_CONTAINER,
+    ...                 'name': 'Execution',
+    ...                 'inputs': {
+    ...                     float: {
+    ...                         'component': FLOAT_INPUT_SLIDER_COMPONENT,
+    ...                         'format': '%.2f',
+    ...                         'step': 0.01,
+    ...                     },
+    ...                     Any: {'component': TEXT_INPUT_COMPONENT,},
     ...                 },
     ...             },
+    ...             'graph': {
+    ...                 'container': SECTION_CONTAINER,
+    ...                 'name': 'Flow',
+    ...                 'component': GRAPH_COMPONENT,
+    ...                 'display': True,
+    ...                 'display_for_single_node': False,
+    ...             }
     ...         },
     ...     },
     ... }
