@@ -1,7 +1,7 @@
 from distutils.command.config import config
 
 from streamlitfront.base import mk_app
-from front.elements import COMPONENT_FLOAT_SLIDER
+from front.elements import FLOAT_INPUT_SLIDER_COMPONENT
 
 
 def foo(a: int = 1, b: int = 2, c=3):
@@ -32,7 +32,9 @@ app = mk_app(
         #     }
         # }
         'rendering': {
-            'Proportion': {'inputs': {'p': {'component': COMPONENT_FLOAT_SLIDER,}},}
+            'Proportion': {
+                'inputs': {'p': {'component': FLOAT_INPUT_SLIDER_COMPONENT,}},
+            }
         },
     },
 )
